==> YNQ-1.5.0_Linux_S_CP.zip: YNQ-1.5.0_Linux_S_CP/NQ Library Reference/html/search/variables_69.js <==
var searchData=
[
  ['icmintent',['icmIntent',['../structSYDeviceMode.html#a9eef7be3372ee18950605e95acf98c36',1,'SYDeviceMode']]],
  ['icmmethod',['icmMethod',['../structSYDeviceMode.html#a8623823c3ec6246c52d781e06d1ccbdb',1,'SYDeviceMode']]],
  ['id',['id',['../structCMCodepage.html#a532e204d4c8b6942b01378c6db51bdf3',1,'CMCodepage::id()'],['../structSYPrintJobInfo.html#a0f6abda1dfbd6d6114104f4f85342c0c',1,'SYPrintJobInfo::id()'],['../structSYPrintFormInfo.html#af7d6c4eb2dd13026681eaa3187829a66',1,'SYPrintFormInfo::id()'],['../structNQ__IPADDRESSVR.html#a0590538056fb61a14cd86cbbe4eb41dc',1,'NQ_IPADDRESSVR::id()']]],
  ['imageablearea',['imageableArea',['../structSYPrintFormInfo.html#a141a7d827786567d30276d28345bdcc3',1,'SYPrintFormInfo']]],
  ['infolevel',['infoLevel',['../structUDFileAccessEvent.html#a390c6cc81fe35b0e22865143443cd682',1,'UDFileAccessEvent']]],
  ['iov_5fbase',['iov_base',['../structNQ__IOVEC.html#ac4b93f3c108c90690b2026168e35f66c',1,'NQ_IOVEC']]],
  ['iov_5flen',['iov_len',['../structNQ__IOVEC.html#ada82b080d48043ba3cfef79fcf32620f',1,'NQ_IOVEC']]],
  ['iovec',['iovec',['../structNQ__IOVECBUF.html#ac3264e5c30f4b9681a769c669f265e7d',1,'NQ_IOVECBUF']]],
  ['iovsegmentcnt',['iovSegmentCnt',['../structNQ__IOVECBUF.html#aaa47cd22b2babcf3749ae39cab150ac3',1,'NQ_IOVECBUF']]],
  ['ip',['IP',['../structFileDataA__t.html#a2859462c4f66f41bb5f61f2728f6b499',1,'FileDataA_t::IP()'],['../structCSFileData.html#a4b3744ba276f572a3918bd4d8f1fab84',1,'CSFileData::IP()'],['../structEVCSShareConnectionEntry.html#a18ea924f9bb758ee646721493ddae4af',1,'EVCSShareConnectionEntry::ip()'],['../structEVCSOpenFileEntry.html#a34e307475e0b55a7430e6b0cbd0ec68c',1,'EVCSOpenFileEntry::ip()']]],
  ['ipc',['ipc',['../structEVCSShareConnectionEntry.html#ab004ff5000b12cfb179ee6292b077c8a',1,'EVCSShareConnectionEntry::ipc()'],['../structUDShareAccessEvent.html#afd3762e274b9919ba3d9b28f3f326b06',1,'UDShareAccessEvent::ipc()']]],
  ['ips',['ips',['../structCCServerInfo.html#a99d713ac4500832a73f75bda8adfdbbc',1,'CCServerInfo']]],
  ['isdeleted',['isDeleted',['../structSYFileInformation.html#aefd5a8cf5445e16cbd4ef636f4b8d1c5',1,'SYFileInformation']]],
  ['isdirectory',['isDirectory',['../structFileDataA__t.html#a075f147a986b999d470788dd85604569',1,'FileDataA_t::isDirectory()'],['../structCSFileData.html#ab882ee6afff2a1b9f36a7dbc2731eee2',1,'CSFileData::isDirectory()']]]
];

==> YNQ-1.6.0_Linux_S_CP.zip: YNQ-1.6.0_Linux_S_CP/NQ Library Reference/html/search/variables_69.js <==
var searchData=
[
  ['icmintent',['icmIntent',['../structSYDeviceMode.html#a9eef7be3372ee18950605e95acf98c36',1,'SYDeviceMode']]],
  ['icmmethod',['icmMethod',['../structSYDeviceMode.html#a8623823c3ec6246c52d781e06d1ccbdb',1,'SYDeviceMode']]],
  ['id',['id',['../structCMCodepage.html#a532e204d4c8b6942b01378c6db51bdf3',1,'CMCodepage::id()'],['../structSYPrintJobInfo.html#a0f6abda1dfbd6d6114104f4f85342c0c',1,'SYPrintJobInfo::id()'],['../structSYPrintFormInfo.html#af7d6c4eb2dd13026681eaa3187829a66',1,'SYPrintFormInfo::id()'],['../structNQ__IPADDRESSVR.html#a0590538056fb61a14cd86cbbe4eb41dc',1,'NQ_IPADDRESSVR::id()']]],
  ['imageablearea',['imageableArea',['../structSYPrintFormInfo.html#a141a7d827786567d30276d28345bdcc3',1,'SYPrintFormInfo']]],
  ['infolevel',['infoLevel',['../structUDFileAccessEvent.html#a390c6cc81fe35b0e22865143443cd682',1,'UDFileAccessEvent']]],
  ['iov_5fbase',['iov_base',['../structNQ__IOVEC.html#ac4b93f3c108c90690b2026168e35f66c',1,'NQ_IOVEC']]],
  ['iov_5flen',['iov_len',['../structNQ__IOVEC.html#ada82b080d48043ba3cfef79fcf32620f',1,'NQ_IOVEC']]],
  ['iovec',['iovec',['../structNQ__IOVECBUF.html#ac3264e5c30f4b9681a769c669f265e7d',1,'NQ_IOVECBUF']]],
  ['iovsegmentcnt',['iovSegmentCnt',['../structNQ__IOVECBUF.html#aaa47cd22b2babcf3749ae39cab150ac3',1,'NQ_IOVECBUF']]],
  ['ip',['IP',['../structFileDataA__t.html#a2859462c4f66f41bb5f61f2728f6b499',1,'FileDataA_t::IP()'],['../structCSFileData.html#a4b3744ba276f572a3918bd4d8f1fab84',1,'CSFileData::IP()'],['../structEVCSShareConnectionEntry.html#a18ea924f9bb758ee646721493ddae4af',1,'EVCSShareConnectionEntry::ip()'],['../structEVCSOpenFileEntry.html#a34e307475e0b55a7430e6b0cbd0ec68c',1,'EVCSOpenFileEntry::ip()']]],
  ['ipc',['ipc',['../structEVCSShareConnectionEntry.html#ab004ff5000b12cfb179ee6292b077c8a',1,'EVCSShareConnectionEntry::ipc()'],['../structUDShareAccessEvent.html#afd3762e274b9919ba3d9b28f3f326b06',1,'UDShareAccessEvent::ipc()']]],
  ['ips',['ips',['../structCCServerInfo.html#a99d713ac4500832a73f75bda8adfdbbc',1,'CCServerInfo']]],
  ['isdeleted',['isDeleted',['../structSYFileInformation.html#aefd5a8cf5445e16cbd4ef636f4b8d1c5',1,'SYFileInformation']]],
  ['isdirectory',['isDirectory',['../structFileDataA__t.html#a075f147a986b999d470788dd85604569',1,'FileDataA_t::isDirectory()'],['../structCSFileData.html#ab882ee6afff2a1b9f36a7dbc2731eee2',1,'CSFileData::isDirectory()']]],
  ['items',['items',['../structCMLinkedListArray.html#adc833e3b90a9b92b44a3699b9fc5c1d9',1,'CMLinkedListArray']]]
];
